#ifndef ConnectionAttributes_h
#define ConnectionAttributes_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/**
   \file    ConnectionAttributes.h
   \brief   connection attributes
   \author  Hugo Pereira
   \version $Revision$
   \date    $Date$
*/

#include "Counter.h"

#include <QDomDocument>
#include <QDomElement>
#include <QList>

//* connection attributes
class ConnectionAttributes: public Counter
{

    public:

    using List = QList<ConnectionAttributes>;

    //* constructor
    ConnectionAttributes( void );

    //* constructor
    ConnectionAttributes( const QDomElement& element );

    //* dom element
    QDomElement domElement( QDomDocument& parent ) const;

    //* equal to operator
    bool operator == (const ConnectionAttributes& other ) const
    {
        return
            host_ == other.host_ &&
            user_ == other.user_;
    }

    //* less than operator
    bool operator < (const ConnectionAttributes& other ) const
    {
        if( host_ != other.host_ ) return host_ < other.host_;
        else return user_ < other.user_;
    }

    //*@name accessors
    //@{

    //* name
    QString name( void ) const
    { return name_; }

    //* host
    QString host( void ) const
    { return host_; }

    //* port
    int port( void ) const
    { return port_; }

    //* user
    QString user( void ) const
    { return user_; }

    //* password
    QString password( void ) const
    { return password_; }

    //* default
    bool isDefault( void ) const
    { return default_; }

    //@}

    //*@name modifiers
    //@{

    //* name
    ConnectionAttributes& setName( const QString& name )
    {
        name_ = name;
        return *this;
    }

    //* host
    ConnectionAttributes& setHost( const QString& host )
    {
        host_ = host;
        return *this;
    }

    //* port
    ConnectionAttributes& setPort( int port )
    {
        port_ = port;
        return *this;
    }

    //* user
    ConnectionAttributes& setUser( const QString& user )
    {
        user_ = user;
        return *this;
    }

    //* password
    ConnectionAttributes& setPassword( const QString& password )
    {
        password_ = password;
        return *this;
    }

    //* default
    void setIsDefault( bool value )
    { default_ = value; }

    //@}

    private:

    //* name
    QString name_;

    //* host
    QString host_;

    //* port
    int port_ = 21;

    //* user
    QString user_;

    //* password
    QString password_;

    //* true if connection is the default one
    bool default_ = false;

};

#endif
