/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionModel.h"
#include "Debug.h"
#include "IconNames.h"
#include "IconEngine.h"

//_______________________________________________
const QString ConnectionModel::columnTitles_[ ConnectionModel::nColumns ] =
{
    tr( "Name" ),
    tr( "Host" ),
    tr( "Port" ),
    tr( "User" )
};

//______________________________________________________________________
ConnectionModel::ConnectionModel( QObject* parent ):
    ListModel<ConnectionAttributes>( parent ),
    Counter( "ConnectionModel" ),
    icon_( IconEngine::get( IconNames::Connection ) )
{}

//______________________________________________________________________
QVariant ConnectionModel::data( const QModelIndex& index, int role ) const
{

    // check index
    if( !contains( index ) ) return QVariant();

    // retrieve associated file info
    const ConnectionAttributes& attributes( get()[index.row()] );

    // return text associated to file and column
    if( role == Qt::DisplayRole ) {

        switch( index.column() )
        {
            case Name: return attributes.name();
            case Host: return attributes.host();
            case Port: return QString::number( attributes.port() );
            case User: return attributes.user();
            default: return QVariant();
        }

    } else if( role == Qt::DecorationRole && index.column() == Name ) {

        return icon_;

    }

    return QVariant();

}

//______________________________________________________________________
QVariant ConnectionModel::headerData(int section, Qt::Orientation orientation, int role ) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}
