#ifndef ConnectionParser_h
#define ConnectionParser_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionAttributes.h"
#include "Counter.h"
#include "Debug.h"
#include "File.h"
#include "XmlDef.h"
#include "XmlError.h"

#include <algorithm>

//* Connection parser based on xml
class ConnectionParser: public Counter
{
    public:

    //* constructor
    ConnectionParser( void ):
        Counter( "ConnectionParser" )
    {}

    //* read from file
    bool read( const File& file );

    //* write to file
    bool write( const File& file );

    //* clear attributes
    void clear( void )
    { attributes_.clear(); }

    //* add attributes
    void add( const ConnectionAttributes& attributes, bool sort = true );

    //* set attributes
    void set( const ConnectionAttributes::List& attributesList )
    {

        clear();
        for( const auto& attributes:attributesList )
        { add( attributes, false ); }

        std::sort( attributes_.begin(), attributes_.end() );

    }

    //* get attributes
    const ConnectionAttributes::List& attributes( void ) const
    { return attributes_; }

    //* Xml error
    const XmlError& xmlError( void ) const
    { return error_; }

    //* retrieve matching attributes
    class SameAttributesFTor
    {

        public:

        //* constructor
        SameAttributesFTor( const ConnectionAttributes& attributes ):
            attributes_( attributes )
        {}

        //* predicate
        bool operator() (const ConnectionAttributes& attributes ) const
        { return attributes == attributes_; }

        private:

        //* predicted attributes
        ConnectionAttributes attributes_;

    };

    private:

    //* xml error message, if any
    XmlError error_;

    //* list of all read TaskBarAttributes
    ConnectionAttributes::List attributes_;

};

#endif
