#ifndef FileSelectionDialog_h
#define FileSelectionDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "QuestionDialog.h"
#include "FileInfo.h"
#include "FileInfoModel.h"
#include "TreeView.h"

#include <QPushButton>
#include <QLayout>

//* handles FileInfo conflicts
class FileSelectionDialog: public QuestionDialog
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    FileSelectionDialog( QWidget*, const QString& = QString() );

    //* set file info list
    virtual void setFiles( const File& local_path, const File& remote_path, const FileInfo::List& files );

    //* update files from list items
    virtual void updateFiles( FileInfo::List& files );

    //* retrieve selected files
    FileInfo::List selectedFiles( void ) const
    { return _model().get( _list().selectionModel()->selectedRows() ); }

    protected Q_SLOTS:

    //* update button states
    virtual void _updateButtons( void );

    protected:

    //* list
    TreeView& _list() const
    { return *list_; }

    //* model
    const FileInfoModel& _model( void ) const
    { return model_; }

    //* model
    FileInfoModel& _model( void )
    { return model_; }

    //* main widget
    QWidget& _mainWidget( void ) const
    { return *mainWidget_; }

    //* main layout
    QVBoxLayout& _mainLayout( void ) const
    { return *mainLayout_; }

    //* work area
    QVBoxLayout& _workLayout( void ) const
    { return *workLayout_; }

    private:

    //* local path
    File localPath_;

    //* remote path
    File remotePath_;

    //* model
    FileInfoModel model_;

    //* main widget
    QWidget* mainWidget_ = nullptr;

    //* list
    TreeView* list_ = nullptr;

    //* work layout
    QVBoxLayout* mainLayout_ = nullptr;

    //* work layout (to add options
    QVBoxLayout* workLayout_ = nullptr;

    //* clear selection button
    QPushButton* clearSelectionButton_ = nullptr;

};

#endif
