/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FtpCommandDialog.h"

#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "TreeView.h"

#include <QHeaderView>
#include <QGroupBox>
#include <QLayout>
#include <QShortcut>
#include <QSplitter>

//____________________________________________________________
FtpCommandDialog::FtpCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "FtpCommandDialog::FtpCommandDialog.\n" );
    setWindowTitle( "Commands - Qftp" );
    setOptionName( "FTP_COMMAND_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    QSplitter* splitter;
    mainLayout().addWidget( splitter = new QSplitter( this ) );
    splitter->setOrientation( Qt::Vertical );

    // macros
    {
        QWidget* container = new QGroupBox( tr( "Macros" ) );
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->addWidget( macroList_ = new TreeView(container) );

        macroList_->header()->hide();
        macroList_->setSortingEnabled( true );
        macroList_->setModel( &macroModel_ );
        macroList_->setOptionName( "FTP_MACRO_LIST" );

        // context menu
        QMenu* menu( new ContextMenu( macroList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, macroList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, macroList_ ) );
    }

    // commands
    {
        QWidget* container = new QGroupBox( tr( "Commands" ) );
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->addWidget( commandList_ = new TreeView(container) );

        commandList_->header()->hide();
        commandList_->setSortingEnabled( true );
        commandList_->setModel( &commandModel_ );
        commandList_->setOptionName( "FTP_COMMAND_LIST" );

        // context menu
        QMenu* menu( new ContextMenu( commandList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, commandList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, commandList_ ) );

    }

    // ok button
    connect( &okButton(), SIGNAL(pressed()), SLOT(close()) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT(close()) );

}

//_____________________________________________________________
void FtpCommandDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "FtpCommandDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
